Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(77)

Unified Diff: remoting/host/win/session_input_injector.h

Issue 1930473003: Adding support for Win+L key combo in Windows host. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Addressing CR feedback Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/win/session_desktop_environment.cc ('k') | remoting/host/win/session_input_injector.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/win/session_input_injector.h
diff --git a/remoting/host/win/session_input_injector.h b/remoting/host/win/session_input_injector.h
index ed818c98cd7c0df61d20e6b0c3a4797e8d5cffaf..5579f1825c65f6d601c0abbda56ae8a1f94f3f7e 100644
--- a/remoting/host/win/session_input_injector.h
+++ b/remoting/host/win/session_input_injector.h
@@ -18,18 +18,18 @@ class SingleThreadTaskRunner;
namespace remoting {
-// Monitors and passes key/mouse events to a nested event executor. Injects
-// Secure Attention Sequence (SAS) when Ctrl+Alt+Del key combination has been
-// detected.
+// Monitors and passes key/mouse events to a nested event executor. Also handles
+// Ctrl+Alt+Del and Win+L key combinations by invoking the given callbacks.
class SessionInputInjectorWin : public InputInjector {
public:
// |inject_sas| is invoked on |inject_sas_task_runner| to generate SAS on
// Vista+.
SessionInputInjectorWin(
scoped_refptr<base::SingleThreadTaskRunner> input_task_runner,
std::unique_ptr<InputInjector> nested_executor,
- scoped_refptr<base::SingleThreadTaskRunner> inject_sas_task_runner,
- const base::Closure& inject_sas);
+ scoped_refptr<base::SingleThreadTaskRunner> execute_action_task_runner,
+ const base::Closure& inject_sas,
+ const base::Closure& lock_workstation);
~SessionInputInjectorWin() override;
// InputInjector implementation.
« no previous file with comments | « remoting/host/win/session_desktop_environment.cc ('k') | remoting/host/win/session_input_injector.cc » ('j') | no next file with comments »
@@ -18,18 +18,18 @@ class SingleThreadTaskRunner;
class SessionInputInjectorWin : public InputInjector {
public:
- // |inject_sas| is invoked on |inject_sas_task_runner| to generate SAS on
- // Vista+.
+ // |inject_sas| and |lock_workstation| are invoked on
+ // |execute_action_task_runner|.
SessionInputInjectorWin(
scoped_refptr<base::SingleThreadTaskRunner> input_task_runner,

Powered by Google App Engine
This is Rietveld 408576698